@@ -23,7 +23,7 @@ use crate::{
     path::XPathBuf,
 };
 
-#[allow(clippy::arithmetic_side_effects)]
+#[expect(clippy::arithmetic_side_effects)]
 pub(crate) fn sys_fanotify_mark(request: UNotifyEventRequest) -> ScmpNotifResp {
     let req = request.scmpreq;
 
@@ -42,8 +42,6 @@ pub(crate) fn sys_fanotify_mark(request: UNotifyEventRequest) -> ScmpNotifResp {
     // SAFETY: Reject undefined/invalid masks.
     // Note, mask is a 64-bit value but kernel uses the lower 32-bits only.
     let is32 = scmp_arch_bits(req.data.arch) == 32;
-    #[allow(clippy::cast_possible_truncation)]
-    #[allow(clippy::cast_possible_wrap)]
     let (mask, narg) = if is32 {
         let mask = match req.data.arch {
             ScmpArch::Ppc => req.data.args[3],
@@ -91,11 +89,11 @@ pub(crate) fn sys_fanotify_mark(request: UNotifyEventRequest) -> ScmpNotifResp {
             drop(sandbox); // release the read-lock.
 
             // SAFETY: SysArg has one element.
-            #[allow(clippy::disallowed_methods)]
+            #[expect(clippy::disallowed_methods)]
             let path = path_args.0.as_ref().unwrap();
 
             // SAFETY: MUST_PATH asserts dir is Some.
-            #[allow(clippy::disallowed_methods)]
+            #[expect(clippy::disallowed_methods)]
             let fd = path.dir.as_ref().map(|fd| fd.as_fd()).unwrap();
 
             // SAFETY:
