@@ -10,7 +10,7 @@ macro_rules! syscall_handler {
     ($request:ident, $body:expr) => {{
         let request_id = $request.scmpreq.id;
 
-        #[allow(clippy::arithmetic_side_effects)]
+        #[expect(clippy::arithmetic_side_effects)]
         match $body($request) {
             Ok(result) => result,
             // SAFETY: Harden against UnknownErrno so as not to
@@ -151,8 +151,7 @@ use crate::{
 };
 
 /// Process the given path argument.
-#[allow(clippy::cognitive_complexity)]
-#[allow(clippy::too_many_arguments)]
+#[expect(clippy::cognitive_complexity)]
 pub(crate) fn sandbox_path(
     request: Option<&UNotifyEventRequest>,
     sandbox: &Sandbox,
@@ -371,7 +370,7 @@ pub(crate) fn sandbox_path(
 /// # Returns
 ///
 /// - `ScmpNotifResp`: Response indicating the result of the syscall handling.
-#[allow(clippy::cognitive_complexity)]
+#[expect(clippy::cognitive_complexity)]
 pub(crate) fn syscall_path_handler<H>(
     request: UNotifyEventRequest,
     syscall_name: &str,
@@ -402,13 +401,11 @@ where
         let crypt = sandbox.enabled(Capability::CAP_CRYPT);
         let hide = !is_fd && sandbox.enabled(Capability::CAP_STAT);
 
-        // EXCEPTION: We do want to return success
-        // to _access_(2) calls to magic paths in
-        // case the sandbox lock allows it.
-        let mut magic = !sandbox.locked_for(req.pid())
-            && memmem::find_iter(syscall_name.as_bytes(), b"access")
-                .next()
-                .is_some();
+        // EXCEPTION: We do want to return success t o _access_(2) calls
+        // to magic paths in case the sandbox lock allows it.
+        let mut magic = !is_fd
+            && !sandbox.locked_for(req.pid())
+            && memmem::find(syscall_name.as_bytes(), b"access").is_some();
 
         let mut paths: [Option<CanonicalPath>; 2] = [None, None];
         for (idx, arg) in path_argv.iter().enumerate() {
@@ -451,7 +448,7 @@ where
 
                     // Handle ftruncate etc. for files with encryption in progress.
                     let crypt_path = if crypt {
-                        #[allow(clippy::disallowed_methods)]
+                        #[expect(clippy::disallowed_methods)]
                         let files = request.crypt_map.as_ref().unwrap();
                         if let Ok(info) = FileInfo::from_fd(&fd) {
                             let files = files.0.lock().unwrap_or_else(|e| e.into_inner());
@@ -466,9 +463,8 @@ where
                         None
                     };
 
-                    let path = if let Some(path) = crypt_path {
-                        // SAFETY: Only regular files are encrypted.
-                        CanonicalPath::new(path, FileType::Reg, arg.fsflags)?
+                    let path = if let Some(crypt_path) = crypt_path {
+                        CanonicalPath::new_crypt(fd.into(), crypt_path)
                     } else {
                         CanonicalPath::new_fd(fd.into(), req.pid())?
                     };
@@ -597,8 +593,24 @@ pub(crate) fn to_atflags(arg: u64, valid: AtFlags) -> Result<AtFlags, Errno> {
     Ok(flags)
 }
 
+// to_mode that strips unknown bits.
 #[inline]
-pub(crate) fn to_mode(arg: u64) -> Result<Mode, Errno> {
+pub(crate) fn to_mode(arg: u64) -> Mode {
+    // Linux VFS only honors these chmod bits (07777).
+    const S_IALLUGO: libc::mode_t = libc::S_ISUID
+        | libc::S_ISGID
+        | libc::S_ISVTX
+        | libc::S_IRWXU
+        | libc::S_IRWXG
+        | libc::S_IRWXO;
+
+    #[expect(clippy::cast_possible_truncation)]
+    Mode::from_bits_truncate((arg as libc::mode_t) & S_IALLUGO)
+}
+
+// to_mode that rejects unknown/invalid bits.
+#[inline]
+pub(crate) fn to_mode2(arg: u64) -> Result<Mode, Errno> {
     let mode = arg
         .try_into()
         .map(|mode: libc::mode_t| mode & !SFlag::S_IFMT.bits())
