@@ -91,12 +91,8 @@ pub(crate) fn handle_sendmsg(
     // Step 1: Handle the address.
     let sandbox = request.get_sandbox();
     let addr = if !addr_remote.is_null() && addr_len > 0 {
-        let (addr, root) = canon_addr(
-            request,
-            &sandbox,
-            get_addr(request, addr_remote as u64, addr_len)?,
-            Capability::CAP_NET_CONNECT,
-        )?;
+        let addr = get_addr(request, addr_remote as u64, addr_len)?;
+        let (addr, root) = canon_addr(request, &sandbox, &addr, Capability::CAP_NET_CONNECT)?;
         match addr_family(&addr) {
             PF_UNIX | PF_INET | PF_INET6 => {
                 // Check for access.
@@ -462,12 +458,8 @@ pub(crate) fn handle_sendmmsg(
         let addr_len = msg.msg_namelen;
         let sandbox = request.get_sandbox();
         let addr_root = if !addr_remote.is_null() && addr_len > 0 {
-            let (addr, root) = canon_addr(
-                request,
-                &sandbox,
-                get_addr(request, addr_remote as u64, addr_len)?,
-                Capability::CAP_NET_CONNECT,
-            )?;
+            let addr = get_addr(request, addr_remote as u64, addr_len)?;
+            let (addr, root) = canon_addr(request, &sandbox, &addr, Capability::CAP_NET_CONNECT)?;
             match addr_family(&addr) {
                 PF_UNIX | PF_INET | PF_INET6 => {
                     // Check for access.
