@@ -114,7 +114,7 @@ pub type PortSet = FixedBitSet;
 pub enum LandlockRule {
     /// landlock(7) filesystem rule
     Fs((AccessFs, String)),
-    /// landlock(7) network fule
+    /// landlock(7) network rule
     Net((AccessNet, PortRange)),
 }
 
@@ -202,7 +202,7 @@ impl NetlinkCmd {
 //   * If `<opt>` is present, split on commas: known flags -> MsFlags; unknown accumulate into `dat`.
 pub(crate) fn parse_bind_cmd(command: &str) -> Result<BindCmd, Errno> {
     // Inner nom parser: returns (remaining, (op, src_str, dst_str, opt_str?))
-    #[allow(clippy::type_complexity)]
+    #[expect(clippy::type_complexity)]
     fn inner(input: &str) -> IResult<&str, (char, &str, &str, Option<&str>)> {
         // Sequence: "bind", one of '+','-','^', <src> (no ':'), ":", <dst> (no ':'), optional ":" + <opt>
         (
@@ -544,7 +544,7 @@ pub fn parse_landlock_cmd(input: &str) -> Result<LandlockCmd, Errno> {
 // Returns Err(EINVAL) on any parse or validation failure.
 pub(crate) fn parse_scmp_cmd(input: &str) -> Result<ScmpCmd, Errno> {
     // Inner parser: action "/" caps op pat.
-    #[allow(clippy::type_complexity)]
+    #[expect(clippy::type_complexity)]
     fn inner(input: &str) -> IResult<&str, (&str, &str, char, &str)> {
         (
             take_while1(|c| c != '/'),
@@ -582,12 +582,9 @@ pub(crate) fn parse_scmp_cmd(input: &str) -> Result<ScmpCmd, Errno> {
                 return Err(Errno::EINVAL);
             }
 
-            // Address argument is only valid for Bind and Connect.
-            let maybe_addr = filter
-                .intersects(Capability::CAP_NET_BIND | Capability::CAP_NET_CONNECT)
-                && filter
-                    .difference(Capability::CAP_NET_BIND | Capability::CAP_NET_CONNECT)
-                    .is_empty();
+            // IP address arguments are only valid for the `inet` set.
+            let maybe_addr = filter.intersects(Capability::CAP_INET)
+                && filter.difference(Capability::CAP_INET).is_empty();
 
             // Pattern resolution.
             let pat = if maybe_addr {
