@@ -705,12 +705,12 @@ impl<'a> Proxy<'a> {
         let mut progressed = false;
         if is_inp || is_rd_hup || is_hup || is_err {
             // Handle readable events.
-            progressed |= client.handle_input(is_ext)?;
+            progressed |= client.handle_input(is_ext).unwrap_or(false);
         }
 
         if is_out || is_hup || is_err {
             // Handle writable events.
-            progressed |= client.handle_output(is_ext)?;
+            progressed |= client.handle_output(is_ext).unwrap_or(false);
         }
 
         if is_rd_hup {
@@ -741,12 +741,12 @@ impl<'a> Proxy<'a> {
             progressed = false;
 
             // Flush queues in both directions first, in case writes were blocking.
-            progressed |= client.handle_output(is_ext)?;
-            progressed |= client.handle_output(!is_ext)?;
+            progressed |= client.handle_output(is_ext).unwrap_or(false);
+            progressed |= client.handle_output(!is_ext).unwrap_or(false);
 
             // After flushing, try to pull more from both peers.
-            progressed |= client.handle_input(is_ext)?;
-            progressed |= client.handle_input(!is_ext)?;
+            progressed |= client.handle_input(is_ext).unwrap_or(false);
+            progressed |= client.handle_input(!is_ext).unwrap_or(false);
         }
 
         Ok(())
