@@ -390,8 +390,8 @@ impl Worker {
         ctx.set_ctl_nnp(true)?;
 
         // Disable Speculative Store Bypass mitigations
-        // with trace/allow_unsafe_spec_exec:1
-        ctx.set_ctl_ssb(flags.allow_unsafe_spec_exec())?;
+        // with trace/allow_unsafe_exec_speculative:1
+        ctx.set_ctl_ssb(flags.allow_unsafe_exec_speculative())?;
 
         // DO NOT synchronize filter to all threads.
         // Main thread will confine itself.
@@ -506,6 +506,7 @@ impl Worker {
         // Restrict pipe2(2) flags.
         // Restrict pipe2(2) using syscall argument cookies.
         let sysname = "pipe2";
+        #[expect(clippy::cast_sign_loss)]
         #[expect(clippy::useless_conversion)]
         match ScmpSyscall::from_name(sysname) {
             Ok(syscall) => {
